#!/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05
#
# (C) Copyright IBM Corp. 2003,2010. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/adm/update_soft_alarm_sched.sh BL_core_schema_8.0.7_8.0.7.8.03_20101223  183212
#
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`

SCRIPTNAME=`basename $0`

usage() {
     echo
     echo "USAGE: "
     echo
     echo "$SCRIPTNAME -m|-mode  <ENABLE | DISABLE | SHOW> [ -p|-path <path> ] [ -n|-name <soft_alarm_name> ] [ -f|-file <filename> ] | -h "
     echo
     echo " -h|-help				: Displays the help message "
     echo " -m|-mode <ENABLE | DISABLE | SHOW>	: (Mandatory)	Allow Enable, Disable or Show mode to be specified on soft alarm "
     echo " -p|-path <path>			: (Optional)	Must be specified if mode is ENABLE or DISABLE and -file is not specified "
     echo "							The path of the soft alarm schedule to be ENABLE or  DISABLE " 
     echo "							Use single quote (') to allow for spaces in the path "
     echo " -n|-name <soft_alarm_name>		: (Optional)	Must be specified if mode is ENABLE or DISABLE and -file is not specified "
     echo "							The name of the soft alarm schedule to be ENABLE or DISABLE "
     echo " 							Use single quote (') to allow for spaces in the soft alarm name "
     echo " -f|-file <filename>			: (Optional)	Can not be used with -p | -path or -n | -name "
     echo "							The name of the input file listing soft alarm schedules to be ENABLE or DISABLE "
     echo
     #echo " Example: "
     #echo " update_soft_alarm_sched.sh -m ENABLE -p '/Schedule/' -n 'Soft Alarm OMCR Schedule' "
     #echo " update_soft_alarm_sched.sh -m ENABLE -p '/Schedule/' -n KCI_Th_ProjTime_Grp_24_Schedule "
     #echo " update_soft_alarm_sched.sh -m DISABLE -f /tmp/DisableSchedules.lst "
     #echo
     #echo " Input file format: "
     #echo " <Soft alarm schedule path>|<Soft alarm schedule name> "
     #echo " /Schedule/|'Soft Alarm OMCR Schedule' "
     #echo " /Schedule/|WBT "
     #echo " /Schedule/|KCI_Th_ProjTime_Grp_24_Schedule "
     #echo
}

pv_mode=''
pv_path=''
pv_name=''
pv_file=''
pv_file_show=''
pv_state=''

#Display usage if no arguments passed
if [ $# -eq 0 ]
then
   usage
   exit 0
fi

#Parse arguments
while [ $# -gt 0 ]
do
    case $1 in
	-m|-mode)
	   shift
	   pv_mode="'"$1"'"
	   ;;
        -p|-path)
	   shift
	   pv_path="'"$1"'"
	   ;;
        -n|-name)
	   shift
	   pv_name="'"$1"'"
	   ;;
        -f|-file)
	   shift
	   pv_file=$1
	   pv_file_show="'"$1"'"
	   ;;
	-h|-help)
	   usage
	   exit 0
	   ;;
        *)
	   echo "${SCRIPTNAME}: Invalid parameter $1 "
	   usage
	   exit 0
     esac
     
     if [ $# -gt 0 ]
     then
          shift
     fi
done

function update_sa_sched
{
sqlplus -s ${DB_CONNECT} <<SQLPLUS
WHENEVER SQLERROR EXIT FAILURE
set verify off
set heading off
set feedback off
set serveroutput on size unlimited
variable returnstatus number

DECLARE
ln_count NUMBER;	
lv_path	 varchar2(500);
BEGIN
   :returnstatus := 1;
   ln_count:= 0;
   lv_path:= nvl($pv_path,'\schedule\');
   
   SELECT 1 INTO ln_count
     FROM sa_schedule_view
    WHERE name = $pv_name
      AND folderid = fs_lookupfolderbypath (replace(lv_path,'/','\'));

   if ln_count = 1 then

       UPDATE sa_schedule_view
          SET scheduleactive = $pv_state,
       	      needs_msg_update = 'Y'
        WHERE name = $pv_name
          AND folderid = fs_lookupfolderbypath (replace(lv_path,'/','\'));

        :returnstatus := 0;
        COMMIT;

        DBMS_OUTPUT.put_line('"'||$pv_name||'"'||' status updated: '||$pv_mode);

   end if;

EXCEPTION
   WHEN NO_DATA_FOUND THEN
   ROLLBACK;
   DBMS_OUTPUT.put_line('Soft alarm schedule '||'"'||$pv_name||'"'||' not found in '||lv_path);
END;
/
EXIT :returnstatus
SQLPLUS
}

function show_sa_sched
{
sqlplus -s ${DB_CONNECT} <<SQLPLUS
WHENEVER SQLERROR EXIT FAILURE
set verify off
set heading off
set feedback off
set serveroutput on size unlimited
variable returnstatus number

DECLARE
CURSOR sa_sched_list IS
SELECT FS_LOOKUPPATHBYFOLDERID(s.folderid) || s.name sched, s.scheduleactive enabled
  FROM sa_schedule_view s
 WHERE periodicity = 'N';
 
ln_count NUMBER; 

BEGIN
   :returnstatus := 1;
   
   SELECT count(*) into ln_count
	 FROM sa_schedule_view s
	WHERE periodicity = 'N';

	IF ln_count > 0 THEN
	   FOR slist IN sa_sched_list LOOP
		   DBMS_OUTPUT.put_line('"'|| slist.sched || '"' || '  enabled: ' || slist.enabled);
		   
	   END LOOP;
	ELSE   
	   DBMS_OUTPUT.put_line('No soft alarm schedule found!');	   
	END IF;   
 
	:returnstatus := 0;

END;
/
EXIT :returnstatus
SQLPLUS
}

#echo "pv_mode = ${pv_mode}"
#echo "pv_name = ${pv_name}"
#echo "pv_path = ${pv_path}"
#echo "pv_file = ${pv_file}"
#echo "pv_file_show = ${pv_file_show}"

#Check mandatory argument: Mode
if [ "$pv_mode" = "''" ] 
then
     echo "${SCRIPTNAME}: Required -mode argument not passed" >&2
     usage
     exit 1
else
     #Check Mode is valid and mandatory arguments
     if [[ "$pv_mode" = "'SHOW'" || "$pv_mode" = "'show'" ]] 
     then
	  if [[ -z "$pv_path" && -z "$pv_name" && -z "$pv_file_show" ]]
	  then
	       #Show soft alarm schedule status
	       show_sa_sched
	       exit 0
          else
	       echo "${SCRIPTNAME}: -name | -path | -file arguments not required for SHOW mode " >&2
	       usage
	       exit 1
          fi

     elif [[ ${pv_mode} = "'ENABLE'" || ${pv_mode} = "'enable'" || ${pv_mode} = "'DISABLE'" || ${pv_mode} = "'disable'" ]] 
     then

          case $pv_mode in
	    "'ENABLE'"|"'enable'")
 		         pv_state="'"Y"'"
		 	 ;;
	    "'DISABLE'"|"'disable'")
			 pv_state="'"N"'"
			 ;;
	  esac

	  #Check -file argument constraint  
          if [ ! -z "$pv_file" ]
	  then

	       if [[ ! -z "$pv_name" || ! -z "$pv_path" ]]
	       then
	            echo "${SCRIPTNAME}: -file cannot be used with -path or -name " >&2 
	            usage
	            exit 1
               fi

	       if [ -e "$pv_file" ]
	       then
		    
                    #Update Soft alarm schedule from input file
		    line_num=0
		    while read line_by_line
		    do
		       line_num=$((line_num+1))
		       #For each record in file
		       echo " $line_by_line " | awk '{print substr($0,1,index($1,"|"))}' | read pv_path
               echo " $line_by_line " | awk '{print substr($0,index($1,"|")+2)}' | read pv_name
                       
		       pv_path="'"$pv_path"'"
                       pv_name="'"$pv_name"'"

		       update_sa_sched
                    done < $pv_file
                    
		    if [ "$line_num" -eq 0 ]
		    then
			 echo "${SCRIPTNAME}: File does not contain any data " >&2
			 exit 1
                    fi 
               else
		    echo "${SCRIPTNAME}: Input file ${pv_file} not found " >&2
		    exit 1
               fi
          fi
          
	  #Check -name and -path arguments constraint
	  if [ -z "$pv_file" ]
	  then

	       if [ "$pv_name" != "''" ]
	       then
                   if [ -z "$pv_path" ]
				   then
						pv_path="'"$pv_path"'"
				   fi
					
                    update_sa_sched
		    exit 0
	       else
	            echo "${SCRIPTNAME}: Required -name arguments not passed " >&2
	            usage
	            exit 0
               fi
	  fi
     else
 	   echo "${SCRIPTNAME}: Invalid mode ${pv_mode} " >&2 
           usage
	   exit 1
     fi
fi

